@@ -15,7 +15,7 @@ from shutil import make_archive, unpack_archive
 
 from cognite.client.exceptions import CogniteNotFoundError, CogniteAPIError
 
-from akerbp.mlops.utils import logger 
+from akerbp.mlops.core import logger 
 
 logging=logger.get_logger(name='cdf_helper')
 
@@ -118,7 +118,8 @@ def deploy_function(
 ):
     """
     Deploys a Cognite function from a folder. The function is created first,
-    and then it waits until the function status is ready or failed.
+    and then it waits until the function status is ready or failed. If it fails,
+    it will try again `max_error` times
 
     Inputs:
       - function_name: name of the function to create
@@ -126,19 +127,25 @@ def deploy_function(
       - handler_path: path to the handler file
       - secrets: api keys or similar that should be passed to the function
     """
+    max_errors = 3
 
-    function = create_function(
-        function_name, 
-        folder, 
-        handler_path, 
-        info['description'],
-        info['owner'],
-        secrets
-    )
-    status = wait_function_status(function)
-    logging.debug(f"Function status is {status}")
-    if function.status == 'Failed':
-        raise Exception(f"Function deployment error: {function.error=}")
+    for trial in range(max_errors):
+        function = create_function(
+            function_name, 
+            folder, 
+            handler_path, 
+            info['description'],
+            info['owner'],
+            secrets
+        )
+        status = wait_function_status(function)
+        logging.debug(f"Function status is {status}")
+        if function.status == 'Ready':
+            break
+        if function.status == 'Failed' and trial < max_errors-1:
+            logging.debug(f"Try to create function again")
+        else:
+            raise Exception(f"Function deployment error: {function.error=}")
 
 
 def call_function(function_name, data):
@@ -148,7 +155,9 @@ def call_function(function_name, data):
     client = global_client["functions"]
     function = client.functions.retrieve(external_id=function_name)
     logging.debug(f"Retrieved function {function_name}")
-    response = function.call(data).get_response()
+    call = function.call(data)
+    logging.debug(f"Called function (call_id={call.id})")
+    response = call.get_response()
     logging.debug(f"Called function: {response=}")
     return response
 
