@@ -22,7 +22,7 @@ ENV = os.environ['ENV'] # Must be set
 SERVICE_NAME = os.environ['SERVICE_NAME']
 LOCAL_DEPLOYMENT = os.getenv('LOCAL_DEPLOYMENT') # Optional
 
-deployment_platform = 'cdf' # 'cdf'
+deployment_platform = 'gc' # 'cdf'
 
 
 def deploy(model_settings):
@@ -122,15 +122,9 @@ def deploy(model_settings):
             if deployment_platform == 'cdf':
                 from akerbp.mlops.cdf.helpers import deploy_function
                 from akerbp.mlops.cdf.helpers import test_function
-
             elif deployment_platform == 'gc': 
                 from akerbp.mlops.gc.helpers import deploy_function
                 from akerbp.mlops.gc.helpers import test_function
-                helpers.replace_string_file(
-                    "$SERVICE_NAME", 
-                    SERVICE_NAME, 
-                    'Dockerfile'
-                )
             else:
                 message = f"Expected 'cdf' or 'gc', got {deployment_platform=}"
                 raise ValueError(message)
